"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _tools = require("./../tools");

const baseStyle = props => {
  const {
    primary
  } = props.theme.colors;
  const focusRing = (0, _tools.mode)({
    boxShadow: "".concat(primary[400], " 0px 0px 0px 2px")
  }, {
    boxShadow: "".concat(primary[500], " 0px 0px 0px 2px")
  })(props);
  return {
    borderRadius: 'sm',
    // '4px'
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    _web: {
      cursor: props.isDisabled ? 'not-allowed' : props.isLoading ? 'default' : 'pointer'
    },
    _focusVisible: {
      _web: {
        outlineWidth: '0',
        style: { ...focusRing
        }
      }
    },
    _loading: {
      opacity: '40'
    },
    _disabled: {
      opacity: '40'
    }
  };
};

function variantGhost({
  colorScheme
}) {
  return {
    _light: {
      _icon: {
        color: "".concat(colorScheme, ".600")
      },
      _hover: {
        bg: "".concat(colorScheme, ".600:alpha.10")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".600:alpha.20")
      }
    },
    _dark: {
      _icon: {
        color: "".concat(colorScheme, ".500")
      },
      _hover: {
        bg: "".concat(colorScheme, ".500:alpha.10")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".500:alpha.20")
      }
    }
  };
}

function variantOutline({
  colorScheme
}) {
  return {
    borderWidth: '1px',
    _light: {
      borderColor: 'muted.300',
      _icon: {
        color: "".concat(colorScheme, ".600")
      },
      _hover: {
        bg: "".concat(colorScheme, ".600:alpha.10")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".600:alpha.20")
      }
    },
    _dark: {
      borderColor: 'muted.700',
      _icon: {
        color: "".concat(colorScheme, ".500")
      },
      _hover: {
        bg: "".concat(colorScheme, ".500:alpha.10")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".500:alpha.20")
      }
    }
  };
}

function variantSolid({
  colorScheme
}) {
  return {
    _icon: {
      color: 'text.50'
    },
    _light: {
      bg: "".concat(colorScheme, ".600"),
      _hover: {
        bg: "".concat(colorScheme, ".700")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".800")
      }
    },
    _dark: {
      bg: "".concat(colorScheme, ".600"),
      _hover: {
        bg: "".concat(colorScheme, ".700")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".800")
      }
    }
  };
}

function variantSubtle({
  colorScheme
}) {
  return {
    _text: {
      color: "".concat(colorScheme, ".900")
    },
    _icon: {
      color: "".concat(colorScheme, ".900")
    },
    _light: {
      bg: "".concat(colorScheme, ".100"),
      _hover: {
        bg: "".concat(colorScheme, ".200")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".300")
      }
    },
    _dark: {
      bg: "".concat(colorScheme, ".300"),
      _hover: {
        bg: "".concat(colorScheme, ".200")
      },
      _pressed: {
        bg: "".concat(colorScheme, ".100")
      }
    }
  };
}

function variantLink({
  colorScheme
}) {
  return {
    _spinner: {
      color: "".concat(colorScheme, ".600")
    },
    _light: {
      _icon: {
        color: "".concat(colorScheme, ".600")
      },
      _hover: {
        _icon: {
          color: "".concat(colorScheme, ".700")
        }
      },
      _pressed: {
        _icon: {
          color: "".concat(colorScheme, ".800")
        }
      }
    },
    _dark: {
      _icon: {
        color: "".concat(colorScheme, ".500")
      },
      _hover: {
        _icon: {
          color: "".concat(colorScheme, ".400")
        }
      },
      _pressed: {
        _icon: {
          color: "".concat(colorScheme, ".300")
        }
      }
    }
  };
}

const variants = {
  ghost: variantGhost,
  outline: variantOutline,
  solid: variantSolid,
  subtle: variantSubtle,
  link: variantLink,
  unstyled: {}
};
const sizes = {
  lg: {
    p: '3',
    _icon: {
      size: 'lg'
    }
  },
  md: {
    p: '2.5',
    _icon: {
      size: 'md'
    }
  },
  sm: {
    p: '2',
    _icon: {
      size: 'sm'
    }
  },
  xs: {
    p: '1.5',
    _icon: {
      size: 'xs'
    }
  }
};
const defaultProps = {
  variant: 'ghost',
  size: 'md',
  colorScheme: 'primary'
};
var _default = {
  baseStyle,
  variants,
  sizes,
  defaultProps
};
exports.default = _default;
//# sourceMappingURL=icon-button.js.map